@@ -35,6 +35,7 @@ BEGIN
      AND variable_name != 'INNODB_BUFFER_POOL_LOAD_AT_STARTUP'
      AND variable_name not like 'GTID%POS'
      AND variable_name != 'GTID_BINLOG_STATE'
+     AND variable_name != 'THREAD_POOL_SIZE'
    ORDER BY variable_name;
 
   -- Dump all databases, there should be none
@@ -70,9 +71,9 @@ BEGIN
   SELECT * FROM INFORMATION_SCHEMA.EVENTS;
   -- Dump all triggers	 except mtr internals, there should be none
   SELECT * FROM INFORMATION_SCHEMA.TRIGGERS
-         WHERE TRIGGER_NAME NOT IN ('gs_insert', 'ts_insert');
+         WHERE TRIGGER_NAME NOT IN ('gs_insert', 'ts_insert') AND TRIGGER_SCHEMA != 'sys';
   -- Dump all created procedures, there should be none
-  SELECT * FROM INFORMATION_SCHEMA.ROUTINES;
+  SELECT * FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_SCHEMA != 'sys';
 
   SHOW STATUS LIKE 'slave_open_temp_tables';
 
@@ -86,7 +87,7 @@ BEGIN
     mysql.help_keyword,
     mysql.help_relation,
     mysql.plugin,
-    mysql.proc,
+--  mysql.proc,
     mysql.procs_priv,
     mysql.roles_mapping,
     mysql.tables_priv,
